-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema nccs
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `nccs` DEFAULT CHARACTER SET utf8 ;
USE `nccs` ;

-- -----------------------------------------------------
-- function func_get_mediafile_Owner
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`func_get_mediafile_Owner`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `func_get_mediafile_Owner`(mediaID int) RETURNS int(11)
BEGIN
  -- 查询文件（夹）最顶层的归属用户（只能查询用户文件夹及其文件）
  -- 用于判断文件（夹）是否挂载在用户文件夹下，而不是系统文件夹下
  declare medid int default null;
  declare pid int default null;
  declare own int default null;
  declare foldflag tinyint default null;

  -- 查询文件（夹）
  select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder,mediafile.MediaID into pid,own,foldflag,medid from MediaFiles mediafile where mediafile.MediaID = mediaID limit 1;
  -- 没找到 或者 查询到了“用户文件”系统文件夹
  if(medid is null) or ((foldflag is not null) and (foldflag = 2)) then
	set own = -1;
	return own;
  else
    -- 查询到了系统创建的用户名最顶层文件夹
	if((foldflag is not null) and (foldflag = 1)) then
	  if(own is null) then
		set own = -1;
	  end if;
	  return own;
	else
      -- 利用PID递归查询文件（夹）
      while((pid is not null) and (pid <> 0)) do
		select mediafile.Parent,mediafile.`Owner`,mediafile.Sysfolder into pid,own,foldflag from MediaFiles mediafile where mediafile.MediaID = pid limit 1;
        -- 没找到 或者 查询到了“用户文件”系统文件夹
	    if(medid is null) or ((foldflag is not null) and (foldflag = 2)) then
		  set own = -1;
		  return own;
	    else
          -- 查询到了系统创建的用户名最顶层文件夹
		  if((foldflag is not null) and (foldflag = 1)) then
		    if(own is null) then
			  set own = -1;
			end if;
			return own;
		  end if;
		end if;
	  end while;
	end if;
    -- 最后没有找到
	set own = -1;
	return own;
  end if;
END$$

DELIMITER ;




-- -----------------------------------------------------
-- function get_idle_sessionid
-- -----------------------------------------------------

USE `nccs`;
DROP function IF EXISTS `nccs`.`get_idle_sessionid`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` FUNCTION `get_idle_sessionid`(video boolean) RETURNS smallint(5) unsigned
begin

declare ses_id smallint unsigned default 1;

 emp_loop: loop
if not exists(select SessionID from PlaySessions where SessionID = ses_id) then
leave emp_loop;
end if;
set ses_id = ses_id + 1;
end loop;

return  ses_id;
end$$

DELIMITER ;





-- -----------------------------------------------------
-- procedure sp_fetch_playing_file
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_fetch_playing_file`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`localhost` PROCEDURE `sp_fetch_playing_file`(
    sesid smallint,
    file_seq int,
    remained_time int)
begin
	declare random tinyint default 0;
	declare maxid int default 0;

    select PlayMode into random from PlaySessions where  SessionID = sesid;

	if (random > 0) then
		if (remained_time <> 0) then
           select max(b.SequenceID) into maxid from PlayListFiles b
				   left join MediaFiles c on b.FileID = c.MediaID
					where b.SessionID = sesid;
		   set maxid = round( rand() * maxid);
		   select b.FileID, c.TotalTime,b.SequenceID, c.Gain, c.FilePath, @@datadir, c.FileName
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID
		               where  (b.SessionID = sesid) and (b.SequenceID >= maxid)
                   order by SequenceID limit 0, 1;
		else
			if (file_seq = 0) then
			    select max(SequenceID) into maxid from PlayListFiles where SessionID = sesid;
			    set maxid = round( rand() * maxid);
			    select b.FileID, c.TotalTime,1, c.Gain, c.FilePath, @@datadir, c.FileName
                   from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID
		           where  (b.SessionID = sesid) and (b.SequenceID >= maxid) order by SequenceID limit 0, 1;
			else
                select null;
            end if;
		  end if;
    else
        select b.FileID, c.TotalTime,b.SequenceID, c.Gain, c.FilePath, @@datadir , c.FileName
               from PlayListFiles b left join MediaFiles c on b.FileID = c.MediaID
		       where  (b.SessionID = sesid) and (b.SequenceID >= file_seq) order by SequenceID limit 0, 1;
    end if;



END$$

DELIMITER ;


-- -----------------------------------------------------
-- procedure sp_create_sub_table
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_create_sub_table`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_create_sub_table`(y INT(11))
BEGIN
	declare tName varchar(50) default '';
	DECLARE yearMax int(11) DEFAULT YEAR(NOW())+1;
	DECLARE yearMin int(11) DEFAULT 2010;
	IF y < yearMin THEN
   set y=yearMin;
END IF;
while y < yearMax  do
		set tName=concat('DevicePower',y);
		SET @param1 =concat('CREATE table IF NOT EXISTS ', tName, ' like ', 'DevicePower');
PREPARE stmt1 FROM @param1;
EXECUTE stmt1;
DEALLOCATE PREPARE stmt1;
set y=y+1;

end while;

END$$

DELIMITER ;

-- -----------------------------------------------------
-- procedure sp_create_sub_table
-- -----------------------------------------------------

USE `nccs`;
DROP procedure IF EXISTS `nccs`.`sp_update_sub_table`;

DELIMITER $$
USE `nccs`$$
CREATE DEFINER=`root`@`%` PROCEDURE `sp_update_sub_table`(t_name VARCHAR(255),sqlStr VARCHAR(1000))
BEGIN
declare done int default false;
declare temp_name varchar(64) default null;
declare cur cursor for select  TABLE_NAME  from information_schema.TABLES where TABLE_NAME like concat(t_name,'%');
DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = TRUE;

open cur;
REPEAT
FETCH cur into temp_name;
	if not done then
				SET @param1=replace(sqlStr,'?',temp_name);
PREPARE stmt1 FROM @param1;
EXECUTE stmt1;
DEALLOCATE PREPARE stmt1;
end if;
until done
END REPEAT;

close cur;

END$$

DELIMITER ;


-- -----------------------------------------------------
-- View `nccs`.`v_device_log`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_device_log` ;
DROP TABLE IF EXISTS `nccs`.`v_device_log`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_device_log` AS select `a`.`DevLogID` AS `DevLogID`,`a`.`DeviceID` AS `DeviceID`,`c`.`Dev_Name` AS `DeviceName`,`a`.`DateTime` AS `DateTime`,`a`.`Event` AS `Event`,`a`.`CtrlUser` AS `CtrlUser`,ifnull(`b`.`User_Desc`,`b`.`User_Name`) AS `User_Name`,`b`.`User_Sn` AS `User_Sn`,`a`.`MsgContext` AS `MsgContext`,`a`.`EndTime` AS `EndTime`,(case `a`.`EndTime` when NULL then NULL else timediff(`a`.`EndTime`,`a`.`DateTime`) end) AS `Length` from ((`nccs`.`DeviceLog` `a` left join `nccs`.`Users` `b` on((`b`.`User_ID` = `a`.`CtrlUser`))) left join `nccs`.`DeviceList` `c` on((`c`.`DevID` = `a`.`DeviceID`))) order by `a`.`DevLogID` desc;


-- -----------------------------------------------------
-- View `nccs`.`v_event`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_event` ;
DROP TABLE IF EXISTS `nccs`.`v_event`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_event` AS select `a`.`Id` AS `Id`,`a`.`Name` AS `Name`,`a`.`StartTask` AS `StartTask`,`b`.`SessionName` AS `StartTaskName`,`a`.`EndTask` AS `EndTask`,`c`.`SessionName` AS `EndTaskName`,hex(`a`.`Config`) AS `Config`,`a`.`Model` AS `Model`,`d`.`Manufacturer` AS `Manufacturer`,`d`.`Model` AS `ModelName`,`a`.`Version` AS `Version` from (((`Event` `a` left join `PlaySessions` `b` on `b`.`SessionID` = `a`.`StartTask`) left join `PlaySessions` `c` on `c`.`SessionID` = `a`.`EndTask`) left join `EventModel` `d` on((`d`.`id` = `a`.`Model`)));

-- -----------------------------------------------------
-- View `nccs`.`v_play_session_time_group`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_play_session_time_group` ;
DROP TABLE IF EXISTS `nccs`.`v_play_session_time_group`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_play_session_time_group` AS (select `a`.`SessionID` AS `SessionID`,cast(`a`.`PlayTime` as time) AS `PlayTime`,group_concat(`a`.`WeekDay` separator ',') AS `WeekDay`,group_concat(`a`.`TempFlag` separator ',') AS `TempFlag`,group_concat(`a`.`ScheduleID` separator ',') AS `ScheduleID` from `nccs`.`PlaySessionTime` `a` group by `a`.`SessionID`,`a`.`PlayTime`);

-- -----------------------------------------------------
-- View `nccs`.`v_playing_sessions`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_playing_sessions` ;
DROP TABLE IF EXISTS `nccs`.`v_playing_sessions`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_playing_sessions` AS select `a`.`SessionID` AS `SessionID`,`a`.`PlayerID` AS `PlayerID`,`a`.`PlayingFileID` AS `PlayingFileID`,`b`.`FileName` AS `FileName`,`a`.`MultiPort` AS `MultiPort`,`a`.`CircleLength` AS `CircleLength`,`a`.`CurrFileProgress` AS `CurrFileProgress`,`a`.`CurrTotalProgress` AS `CurrTotalProgress`,`a`.`Priority` AS `Priority`,`a`.`Pause` AS `Pause`,`a`.`ScheduleID` AS `ScheduleID`,`d`.`WeekDay` AS `WeekDay`,cast(`d`.`PlayTime` as time) AS `PlayTime`,`c`.`Template` AS `Template`,`a`.`BrdMode` AS `BrdMode`,`a`.`SesType` AS `SessionType`,`a`.`StreamType` AS `StreamType` from (((`nccs`.`PlayingSessions` `a` left join `nccs`.`MediaFiles` `b` on((`a`.`PlayingFileID` = `b`.`MediaID`))) left join `nccs`.`PlaySessions` `c` on((`c`.`SessionID` = `a`.`SessionID`))) left join `nccs`.`PlaySessionTime` `d` on((`d`.`ScheduleID` = `a`.`ScheduleID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_session_info`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_session_info` ;
DROP TABLE IF EXISTS `nccs`.`v_session_info`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_session_info` AS select `a`.`SessionID` AS `SessionID`,`a`.`SessionName` AS `SessionName`,`a`.`SessionType` AS `SessionType`,`a`.`Priority` AS `Priority`,`a`.`CircleLength` AS `CircleLength`,`a`.`PlayerID` AS `PlayerID`,`a`.`BrdMode` AS `BrdMode`,`a`.`MemberMode` AS `MemberMode`,`a`.`StreamType` AS `StreamType`,`a`.`Owner` AS `Owner`, `a`.`CreateSource` AS `CreateSource`, if(isnull(`d`.`User_Desc`),`d`.`User_Name`,`d`.`User_Desc`) AS `OwnerName`,`a`.`PlayMode` AS `PlayMode`,`a`.`AudioGain` AS `AudioGain`,`a`.`Template` AS `Template`,`b`.`FileID` AS `FileID`,`c`.`IpAddress` AS `PlayerAddress`,`c`.`PlayType` AS `PlayType`,`e`.`PlayerType` AS `PlayerType`,`f`.`ChildType` AS `ChildType`,`f`.`State` AS `State`,`f`.`Action` AS `Action`,(case when ((`f`.`ChildType` is not null) or (`a`.`StreamType` = 0)) then 'ctrl' else 'brd' end) AS `Type` from (((((`nccs`.`PlaySessions` `a` left join `nccs`.`PlayListFiles` `b` on(((`b`.`SessionID` = `a`.`SessionID`) and (`b`.`SequenceID` = 0)))) left join `nccs`.`PlayerStatus` `c` on((`c`.`PlayerID` = `a`.`PlayerID`))) left join `nccs`.`Users` `d` on((`d`.`User_ID` = `a`.`Owner`))) left join `nccs`.`Players` `e` on((`e`.`PlayerID` = `a`.`PlayerID`))) left join `nccs`.`SessionCtrlListType` `f` on((`a`.`SessionID` = `f`.`SessionID`)));

-- -----------------------------------------------------
-- View `nccs`.`v_timed_session_info`
-- -----------------------------------------------------
DROP VIEW IF EXISTS `nccs`.`v_timed_session_info` ;
DROP TABLE IF EXISTS `nccs`.`v_timed_session_info`;
USE `nccs`;
CREATE  OR REPLACE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `nccs`.`v_timed_session_info` AS select `a`.`SessionID` AS `SessionID`,`a`.`SessionName` AS `SessionName`,`a`.`SessionType` AS `SessionType`,`a`.`Priority` AS `Priority`,`a`.`BrdMode` AS `BrdMode`,`a`.`StreamType` AS `StreamType`,`a`.`Owner` AS `Owner`,`a`.`OwnerName` AS `OwnerName`,`a`.`PlayMode` AS `PlayMode`,`a`.`Template` AS `Template`,`a`.`FileID` AS `FileID`,`d`.`PlayTime` AS `PlayTime`,`d`.`WeekDay` AS `WeekDay`,`d`.`TempFlag` AS `TempFlag`,`d`.`ScheduleID` AS `ScheduleID`,`a`.`Type` AS `Type` from (`nccs`.`v_play_session_time_group` `d` left join `nccs`.`v_session_info` `a` on((`d`.`SessionID` = `a`.`SessionID`))) where (`a`.`SessionType` in (0,8));
DELIMITER $$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`BrdModeMember_AFTER_DELETE` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`BrdModeMember_AFTER_INSERT` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_brdmode_update1` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devclasses_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceList_AFTER_INSERT` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceList_AUPD` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devicelist_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_DeviceDesiredStaus_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceStatistic_after_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceStatistic_after_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_changed1` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_del` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_dev_instert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_devstatus_before_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceStatusExt_after_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceStatusExt_after_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`DeviceStatusExt_after_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_delete_player` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_insert_player` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_user_update_player` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_TaskTemplate_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_session_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_play_Schedule_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`Event_before_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`bef_media_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_after_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_media_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_del` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_ins` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_playing_ses_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_del` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_ins` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_ses_dev_ses_update` $$

USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`SrsServer_after_delete` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`SrsServer_after_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`SrsServer_after_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`SrsServerStatus_before_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`Timetable_before_update` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`Timetable_befroe_insert` $$
USE `nccs`$$
DROP TRIGGER IF EXISTS `nccs`.`tr_userdev_delete` $$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_IcCard_Authorize`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_check_dev_stream`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_check_mode_daytime`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_check_mode_enabled`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_check_session_daytime`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_check_task_privilege`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_dulicate_device`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_get_dev_mode`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`func_qrcode_request`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`get_dev_mode`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`get_dev_session`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`get_idle_port`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`get_network`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`get_rtmp_url`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_check_group`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_copy_mode`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_copy_template`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_del_media_class`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_del_media_file`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_del_session_class`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_delete_device`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_delete_group`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`sp_dev_belong_group`$$

USE `nccs`$$
DROP function IF EXISTS `nccs`.`sp_dev_belong_logic_class`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_device_statistics`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_ipcall_check`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_ipcall_check`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_player_keepalive`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_send_dev_cfg_cmd`$$

USE `nccs`$$
DROP procedure IF EXISTS `nccs`.`sp_update_realtime_session`$$

USE `nccs`$$
DROP VIEW IF EXISTS `nccs`.`v_Session_Files` $$
DROP TABLE IF EXISTS `nccs`.`v_Session_Files`$$

USE `nccs`$$
DROP VIEW IF EXISTS `nccs`.`v_device_statistic` $$
DROP TABLE IF EXISTS `nccs`.`v_device_statistic`$$

USE `nccs`$$
DROP VIEW IF EXISTS `nccs`.`v_timetable` $$
DROP TABLE IF EXISTS `nccs`.`v_timetable`$$

USE `nccs`$$
DROP VIEW IF EXISTS `nccs`.`v_timetable_v1` $$
DROP TABLE IF EXISTS `nccs`.`v_timetable_v1`$$

DELIMITER ;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
